{% extends 'layout.html' %} {% set crumbs = (('Docs',), ('Config',)) %} {% set toc = ( ('archive_layout',), ('archives_url',), ('assets_url',), ('base_url',), ('containers',), ('date_format',), ('domain',), ('include',), ('locale',), ('posts_order',), ('posts_sort',), ('posts_url',), ('pygmentize',), ('renderer',), ('tag_layout',), ('tags_url',) ) %} {% block content %}

archive_layout: None

  The template used to generate archive pages.

  Must be set to enable automatic archive page generation.

archives_url: /
  The base URL for archive pages.
assets_url: /assets/
  The URL, from `base_url`, assets will be served from after generation.
base_url: /
  The URL the site will be served from after generation.
containers: {}

  A dictionary of content containers and their settings. The container's name is stored in the key while it's settings in the value as a dictionary. They have the following settings available:

  Setting | Default
  --- | ---
  archive_layout | None
  archives_url | /
  order | desc
  sort | timestamp
  tag_layout | None
  tags_url | /
  url | None

date_format: %A, %B %d, %Y
  The format of `post.date`.
domain: None
  The domain the site will be served from after generation.
include: []
  A list of glob patterns specifying directories and files to be copied over that would otherwise be ignored.
locale: None
  The locale used by the renderer.
posts_order: desc
  The order in which posts are sorted. Can be set to `asc` or `desc`.
posts_sort: timestamp
  The attribute posts are sorted by.
posts_url: /<year>/<month>/<day>/<slug>/

  The format of `posts.url`.

  Variable | Description
  --- | ---
  <day> | Day of the post as a decimal.
  <i_day> | Day of the post as an integer without leading zeros.
  <i_month> | Month of the post as an integer without leading zeros.
  <month> | Month of the post as a decimal.
  <slug> | The slugified title of the post.
  <year> | Year of the post with century.

  Frontmatter attributes containing string values can be used in URL formats. For example, if all of your posts have an `author` attribute you could use it in your URL format like so: `/<author>/<slug>/`.

pygmentize: True

  Whether or not code highlighting is enabled.

  You can highlight code in Markdown by using fenced code blocks.

      ```html
      <p>highlight me</p>
      ```

  Or you can highlight code in HTML by simply setting the `data-lang` attribute of the `<code>` tag.

      <pre><code data-lang="html">highlight me</code></pre>

  You'll probably want a stylesheet for your highlighted code. You can read more about styles in Pygments here if you want to make your own, or you can grab one of the stylesheets included with Pygments from here.

renderer: jinja
  The renderer used.
tag_layout: None

  The template used to generate tag pages.

  Must be set to enable automatic tag page generation.

tags_url: /
  The base URL for tag pages.

{% endblock %}